#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-78iRkwjTMmGGIR2bvJufIi
key:                  ghcide-2.3.0.0-78iRkwjTMmGGIR2bvJufIi
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  ab1690e895985810bdefda40aa158f1f
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-78iRkwjTMmGGIR2bvJufIi
depends:
    Diff-1.0-JevffVw1iEcKOsohkA0eR5 Glob-0.10.2-DBSEiEVfVQS3ZBCsijATqX
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT array-0.5.6.0
    async-2.2.6-13RsU0DgnQr2Fu0srq1209 base-4.18.2.1
    base16-bytestring-1.0.2.0-Dowr9jBdlVZBVCdnm9XhEq binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    co-log-core-0.3.2.6-FmE7DibPRp4ExxoIsKSQFv containers-0.6.7
    cryptohash-sha1-0.11.101.0-HXk16cNaAybHdJ4S2vrEoS
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-5qUqLl91AbZ2bKmfIMu2xO
    dependent-sum-0.7.2.0-65xV7Vh7s326iKkcnZxDOe directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-2iVxWxnDoGf6b1G5zYwTUG exceptions-0.10.7
    extra-1.7.16-5TJRL61mQdJ37nJ79jr8U filepath-1.4.300.1
    fingertree-0.1.6.3-KWZewXJzuylIHgrI8BMyjj
    focus-1.0.3.2-1HYjHoqUe6rKdwNpxbWKi7 ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-5mEfnr4mzKLFRFjI5D8Pml
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-E7Z1DiNNJCd7k8i6L1frbj
    hashable-1.4.7.0-AuDVFqXH7XaG9xiVOVTNBi
    hie-bios-0.12.0-IaUq6Ldfd7JCTtEdjw30Zh
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-I2TIZPLmsU77RUeBojIIkv
    hls-graph-2.3.0.0-4X3yADOKJezCfW676tAtn2
    hls-plugin-api-2.3.0.0-PV4VuNiiei50o1roJRQC9
    implicit-hie-0.1.4.0-JRR3qJF11j7K06SCWbevlM
    implicit-hie-cradle-0.5.0.1-5FGfwyQk6L43D9nCgCB1IR
    lens-5.3.4-CugvPwDQfTKJtJ2DRsVKfV
    list-t-1.0.5.7-4o8px51VJPk8IJzCcRoELK
    lsp-2.2.0.0-ASJx8lMy3AeIMffE9ZbIv9
    lsp-types-2.0.2.0-9I6W00SGQct8ofSsEutf7C mtl-2.3.1
    opentelemetry-0.8.0-89NSa3XArLKGLX4fRY9ZFi
    optparse-applicative-0.18.1.0-7VN2J9FD8HH2Bl1L5dRVhn
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-E27IB52rJzT5cRmoGOw0uk
    prettyprinter-ansi-terminal-1.1.4-EynbTVBvtsu8QE6iORmNaN
    random-1.2.1.3-8RkfyIpOhzwIqsi8QOPf6g
    regex-tdfa-1.3.2.5-BeZN9DGCtsf7yikLZxv9p
    row-types-1.0.1.2-5hwpxSgR0dCfLegwSqtEH
    safe-exceptions-0.1.7.4-3wk6Rchm5LTH7MUPQ2VD18
    sorted-list-0.2.3.1-4ZkBtdwxEmkHwMxBDlGl25
    sqlite-simple-0.4.19.0-CBYT7e2xIwTIBJpsvxSn0Q stm-2.5.1.0
    stm-containers-1.2.1.1-9vywzJzSFnZAfiR1dsCF7c
    syb-0.7.3-IWvKvWWONKwAx7053zcTAl text-2.0.2
    text-rope-0.3-GW3MBK1abxUAT5i8yEV7h8 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-8Cmk1kbG8582HEPFTOgSAB
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

